/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.addons.apstractSystemAdapter;

import gamf.addons.junittests.DummyEventGenerator;
import gamf.framework.exceptions.ConfigurationError;
import gamf.framework.exceptions.EventGenerationException;
import gamf.interfaces.systemAdapter.IEventGenerator;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;

import uk.ac.standrews.cs.nds.eventModel.Event;
import uk.ac.standrews.cs.nds.eventModel.IEvent;
import uk.ac.standrews.cs.nds.eventModel.TimeStampedEvent;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventBus;
import uk.ac.standrews.cs.nds.util.Diagnostic;

/**
 * Provides the functionalities a standard event generator is envisioned to
 * have. I.e. sending events to the GAMF after being registered with the GAMF.
 * An implementation of this event generator can be seen in the junit test
 * package ({@link DummyEventGenerator}).
 * 
 * @author Markus
 * 
 */
public class EventGenerator extends SystemAdapter implements IEventGenerator {

	protected HashSet<String> localEventTypes;
	protected String eventGeneratorCategory;
	protected String eventGeneratoreIdentifier;
	protected IEventBus managerEventBus;
	protected static String DEFAULT_EVENT_MSG_ID = "DEFAULT_EVENT_MSG_ID";

	public EventGenerator(String systemAdapterID, String systemAdapterCategory) {
		super(systemAdapterID, systemAdapterCategory);
		localEventTypes = new HashSet<String>();
	}

	public Iterator<String> queryEventTypes() {
		return localEventTypes.iterator();
	}

	public void setEventBus(IEventBus eventBus) {
		managerEventBus = eventBus;
	}

	protected void publish(IEvent event) throws ConfigurationError {
		if (managerEventBus != null) {
			Diagnostic.trace(event.getType() + " published");
			managerEventBus.publishEvent(event);
		} else {
			throw new ConfigurationError("event bus not initialised");
		}
	}

	public void triggerEventGeneration(String eventType,
			Map<String, String> msgs) throws EventGenerationException {
		IEvent event = new TimeStampedEvent(eventType);

		for (String msgID : msgs.keySet()) {
			event.put(msgID, msgs.get(msgID));
		}
		try {
			publish(event);
		} catch (ConfigurationError e) {
			throw new EventGenerationException(e);

		}
	}

	public void triggerEventGeneration(String eventType, String msg)
			throws EventGenerationException {
		Map<String, String> msgs = new HashMap<String, String>();
		msgs.put(DEFAULT_EVENT_MSG_ID, msg);
		triggerEventGeneration(eventType, msgs);
	}

	public void triggerEventGeneration(String eventType)
			throws EventGenerationException {
		try {
			publish(new TimeStampedEvent(eventType));
		} catch (ConfigurationError e) {
			throw new EventGenerationException(e);

		}

	}

}
