/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.addons.apstractSystemAdapter;

import gamf.addons.junittests.DummyMetricExtractor;
import gamf.framework.exceptions.ConfigurationError;
import gamf.interfaces.framework.IEventStore;
import gamf.interfaces.framework.IGAMF;
import gamf.interfaces.systemAdapter.IMetricExtractor;

/**
 * Provides the functionalities a standard metric extractor is envisioned to
 * have. I.e. extracting monitoring data (events) from the GAMF after being
 * itself registered with the GAMF. An implementation of this metric extractor
 * can be seen in the junit test package ({@link DummyMetricExtractor}).
 * 
 * @author Markus
 * 
 */

public abstract class MetricExtractor extends SystemAdapter implements IMetricExtractor {

	

	IEventStore eventStore;
	IGAMF manager;

	protected String metricEvaluatorIdentifier, metricEvaluatorCategory;

	
	public MetricExtractor(String systemAdapterID, String systemAdapterCategory) {
		super(systemAdapterID, systemAdapterCategory);
	}
	
	public void setManagerReferece(IGAMF manager) {
		this.manager = manager;
	}


	protected IEventStore gimmeEventStore() throws ConfigurationError {
		if (manager != null) {
			return manager.getEventStore();
		} else {
			throw new ConfigurationError(
					"The metric extractor has to be registred with the manager to access event store");
		}

	}

	

}
