/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package gamf.addons.apstractSystemAdapter;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import com.sun.org.apache.bcel.internal.generic.NEWARRAY;

import gamf.framework.exceptions.PolicyEvaluationException;
import gamf.interfaces.framework.IGAMF;
import gamf.interfaces.systemAdapter.IEffector;
import gamf.interfaces.systemAdapter.IPolicyEvaluator;

public abstract class PolicyEvaluator extends SystemAdapter implements
		IPolicyEvaluator {

	/**
	 * Provides the functionalities a standard policy evaluator is envisioned to
	 * have. I.e. accessing extracted monitoring data (via metric evaluators)
	 * from the GAMF and changing a target system's tuning knob after being
	 * itself registered with the GAMF. An implementation of this policy
	 * evaluator can be seen in the junit test package ({@link DummyPolicyExtractor}).
	 * 
	 * @author Markus
	 * 
	 */

	protected IGAMF manager;
	protected List<IEffector> effectors;

	public PolicyEvaluator(String policyEvaluatorID,
			String policyEvaluatorCategory) {
		super(policyEvaluatorID, policyEvaluatorCategory);
		effectors = new ArrayList<IEffector>();
	}

	public Iterator<IEffector> getEffectors() {
		return effectors.iterator();
	}

	public void setManagerReferece(IGAMF manager) {
		this.manager = manager;

	}

	public void associateEffectorWithPolicyEvaluator(IEffector effector) {
		effectors.add(effector);
	}

}
