/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.addons.junittests;

import static org.junit.Assert.*;

import org.junit.Before;
import org.junit.Test;

import gamf.framework.GenericAutonomicManagementFramework;
import gamf.framework.exceptions.DoubleManagedFacetNameOccurenceException;
import gamf.framework.exceptions.DoubleEventTypeOccuranceException;
import gamf.framework.exceptions.NotRegisteredManagedFacetReference;
import gamf.framework.exceptions.TypeMissMatch;
import gamf.interfaces.framework.IManagedFacet;
import gamf.interfaces.framework.IGAMF;
import gamf.interfaces.systemAdapter.IEffector;

/**
 * Tests if an effector can be created and added to the manager without throwing
 * any exception.
 * 
 * @author markus
 * 
 */

public class EffectorTests {

	IGAMF junitManager;

	IManagedFacet managedFacet;

	IEffector dummyEffector, dummyEffector2;

	/**
	 * creates a manager, a managedFacet and 2 effectors
	 * 
	 */

	@Before
	public void setUp() {
		junitManager = new GenericAutonomicManagementFramework();
		try {
			managedFacet = junitManager
					.registerManagedFacet("dummy managedFacet");
		} catch (DoubleManagedFacetNameOccurenceException e) {

			e.printStackTrace();
		}
		dummyEffector = new DummyEffector();
		dummyEffector2 = new DummyEffector();

	}

	/**
	 * adds the to effectors to the manager
	 * 
	 * @throws NotRegisteredManagedFacetReference
	 * @throws DoubleEventTypeOccuranceException
	 */

	@Test
	public void addTwoEffectorsOneManagedFacet()
			throws NotRegisteredManagedFacetReference,
			DoubleEventTypeOccuranceException {

		junitManager.add(dummyEffector, managedFacet);
		junitManager.add(dummyEffector2, managedFacet);
	}

	/**
	 * get and set tuning knob values via the dummy effector
	 */

	@Test
	public void adaptingTuningKnob() {

		Integer tuningKnob = (Integer) dummyEffector.get();
		if (tuningKnob != null) {
			fail("when calling get on the tuning knob the first time it is expected to return null!, thuning know is "
					+ tuningKnob);
		}

		Integer newTuningKnobValue = 124;
		try {
			dummyEffector.set(newTuningKnobValue);
		} catch (TypeMissMatch e) {
			fail("the tuning knob is of the correct type but threw a type missmatch error!");
		}

		tuningKnob = (Integer) dummyEffector.get();
		if (tuningKnob != newTuningKnobValue) {
			fail("tuning know is expected to be " + newTuningKnobValue
					+ " , but tuning know is " + tuningKnob);
		}

		// dummyEffector.set(value)
	}
}
