/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.addons.junittests;

import static org.junit.Assert.assertTrue;

import java.util.List;

import org.junit.Test;

import gamf.framework.EventStore;
import gamf.framework.exceptions.EventStoreExecption;
import gamf.interfaces.framework.IEventStore;
import uk.ac.standrews.cs.nds.eventModel.Event;
import uk.ac.standrews.cs.nds.eventModel.ITimeStampedEvent;
import uk.ac.standrews.cs.nds.eventModel.TimeStampedEvent;
import uk.ac.standrews.cs.nds.util.Diagnostic;
import uk.ac.standrews.cs.nds.util.DiagnosticLevel;

/**
 * Tests the semantics of the {@link IEventStore} interface
 * 
 * @author markus
 */
public class EventStoreAccessTests {

	static IEventStore eventStore;
	static String eventType = "TEST_EVENT";
	static String EVENT_INFO = "EVENT_INFO";

	@SuppressWarnings("serial")
	public class FakeTimeStampedEvent extends Event implements
			ITimeStampedEvent {
		private long creationTime;

		public FakeTimeStampedEvent(String type, long creationTime) {
			super(type);
			this.creationTime = creationTime;
		}

		public long getEventCreationTime() {
			return creationTime;
		}
	}

	// @BeforeClass
	// TODO check why this needs to be a constructor and not only a setup method
	public EventStoreAccessTests() throws Exception {
		Diagnostic.setLevel(DiagnosticLevel.NONE);
		eventStore = new EventStore();
		long oldTimeStamp = System.currentTimeMillis() - 100;
		ITimeStampedEvent oldEvent = new FakeTimeStampedEvent(eventType,
				oldTimeStamp);
		oldEvent.put(EVENT_INFO, "I am old");
		eventStore.add(oldEvent);

		ITimeStampedEvent newEvent = new TimeStampedEvent(eventType);
		newEvent.put(EVENT_INFO, "I am new");
		eventStore.add(newEvent);

	}

	/**
	 * Tests if all events in a specified time window are returned, the oldest
	 * returned event must be in the time window!!
	 * 
	 * @throws EventStoreExecption
	 */
	@Test
	public void getEventsOfTypeInSpecifiedTimeWindow()
			throws EventStoreExecption {

		long oldestEventWeAreInterestedIn = System.currentTimeMillis() - 99;
		List<ITimeStampedEvent> events = eventStore.getLatestEventsOfType(
				eventType, oldestEventWeAreInterestedIn);
		long oldestReturnedEvent = 0;
		for (ITimeStampedEvent event : events) {
			Diagnostic.trace(DiagnosticLevel.FULL, event.get(EVENT_INFO));
			oldestReturnedEvent = event.getEventCreationTime();
		}
		assertTrue(oldestReturnedEvent >= oldestEventWeAreInterestedIn);
	}
}
