/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.addons.junittests;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.junit.Before;
import org.junit.Test;


import gamf.framework.ManagedFacet;
import gamf.framework.GenericAutonomicManagementFramework;
import gamf.framework.exceptions.DoubleManagedFacetNameOccurenceException;
import gamf.framework.exceptions.DoubleEventTypeOccuranceException;
import gamf.framework.exceptions.EventGenerationException;
import gamf.framework.exceptions.NotRegisteredManagedFacetReference;
import gamf.interfaces.framework.IManagedFacet;
import gamf.interfaces.framework.IGAMF;
import gamf.interfaces.systemAdapter.IEventGenerator;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventBus;


/**
 * Tests to verify that there can't be managedFacets of similar type or system adapter assigned to "no registered" managedFacets.
 *
 * @author markus
 *
 */

public class ManagedFacetsTests {
	IGAMF junitManager;

	String junitManagedFacetName1,junitManagedFacetSimilarToName1;

	@Before public void initialize(){
		junitManager = new GenericAutonomicManagementFramework();
		junitManagedFacetName1 = "junit managedFacet name 1";
		junitManagedFacetSimilarToName1 = "junit managedFacet name 1";

	}

	/**
	 * Tests if the strings used in adding2similarManagedFacetNames() are similar.
	 *
	 */
	@Test public void checkIfManagedFacetNamesAreSimilar(){
		assertTrue("this test and the following fails if the strings are not equal",junitManagedFacetName1.equals(junitManagedFacetSimilarToName1));

	}

	/**
	 * Tests if the manager detects when an managedFacet is created of an already registered managedFacet type.
	 * The test succeeds if an exception is thrown in the event of the creation of an managedFacet with an managedFacet type already in use.
	 *
	 *
	 * @throws DoubleManagedFacetNameOccurenceException
	 */

	@Test(expected = DoubleManagedFacetNameOccurenceException.class)
    public void adding2similarManagedFacetNames()
            throws DoubleManagedFacetNameOccurenceException {

		try {
			junitManager.registerManagedFacet(junitManagedFacetName1);

		} catch (DoubleManagedFacetNameOccurenceException exception) {
			fail("first call should not throw an exception");

		}


			junitManager.registerManagedFacet(junitManagedFacetSimilarToName1);
			fail("after creating managedFacet with 2 similar names - an exception should have had thrown. If no exception is thrown, this test fails");

	}


	/**
	 * Tests if the managedFacet a systemAdapter is registered with is itself registered.
	 * The system adapter used in here is an eventGenerator (for no reason)
	 * The Test fails if the system adapter can be added to the manager
	 * and registered managedFacet that is not registered with the manager.
	 * The test succeeds if that is prevented by the manager and an exception is thrown.
	 *
	 * @throws NotRegisteredManagedFacetReference
	 * @throws DoubleEventTypeOccuranceException
	 * @throws DoubleEventTypeOccuranceException
	 */

	@Test(expected = NotRegisteredManagedFacetReference.class)
    public void addSystemAdapter() throws NotRegisteredManagedFacetReference,
            DoubleEventTypeOccuranceException {

		junitManager.setDependencyDetection(false);

		IManagedFacet fakeManagedFacet = new ManagedFacet("fake managedFacet");

		@SuppressWarnings("unused")
		class junitEventGenerator implements IEventGenerator {
			Set<String> localEventTypes;
			IEventBus managerEventBus;

			public junitEventGenerator() {
				localEventTypes = new HashSet<String>();

				localEventTypes.add("fake event type");
			}


			public Iterator<String> queryEventTypes() {
				return localEventTypes.iterator();
			}

			public void setEventBus(IEventBus eventBus) {
				managerEventBus =eventBus;
			}

			public String getSystemAdapterCategory() {

				return null;
			}

			public String getSystemAdapterIdentifier() {

				return null;
			}



			public void triggerEventGeneration(String eventType, String msgs) {
				// TODO Auto-generated method stub
				
			}


			public void triggerEventGeneration(String eventType) {
				// TODO Auto-generated method stub
				
			}


			public void triggerEventGeneration(String eventType,
					Map<String, String> msgs) throws EventGenerationException {
				// TODO Auto-generated method stub
				
			}

		}

		IEventGenerator eventGenerator=new DummyEventGenerator();

			//Dont care about double event types in this test
			junitManager.add(eventGenerator, fakeManagedFacet);
			


	}
}
