/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.addons.junittests;

import static org.junit.Assert.fail;
import gamf.framework.GenericAutonomicManagementFramework;
import gamf.framework.exceptions.ConfigurationError;
import gamf.framework.exceptions.DoubleEventTypeOccuranceException;
import gamf.framework.exceptions.DoubleManagedFacetNameOccurenceException;
import gamf.framework.exceptions.MetricExtractionException;
import gamf.framework.exceptions.NotRegisteredManagedFacetReference;
import gamf.interfaces.framework.IEventTrigger;
import gamf.interfaces.framework.IGAMF;
import gamf.interfaces.framework.IManagedFacet;
import gamf.interfaces.framework.IMetricResult;
import gamf.interfaces.systemAdapter.IEventGenerator;
import gamf.interfaces.systemAdapter.IMetricExtractor;

import org.junit.BeforeClass;
import org.junit.Test;

/**
 * This tests evaluate if a MetricExtractor can be created, added to the manager
 * and if it cooperates with other systemAdapter components. The systemAdapter
 * used in here are the ones from the webServerExample package.
 * 
 * @author markus
 * 
 */

public class MetricExtractorTests {

	static IGAMF junitManager;

	static IManagedFacet managedFacet;

	static String junitManagedFacetName1;

	String junitManagedFacetSimilarToName1;

	static IEventGenerator eventGenerator;

	/**
	 * Creates a manager, an managedFacet (within the manager) and adds an
	 * eventGenerator and populates the event store.
	 * 
	 * @throws ConfigurationError
	 * 
	 */

	@BeforeClass
	public static void initialize() throws ConfigurationError {
		junitManager = new GenericAutonomicManagementFramework();
		junitManagedFacetName1 = JunitTestRegister.MANAGEDFACETNAME1;

		// dont care about that exceptions in this test case
		try {
			managedFacet = junitManager
					.registerManagedFacet(junitManagedFacetName1);
		} catch (DoubleManagedFacetNameOccurenceException e) {
			e.printStackTrace();
		}

		eventGenerator = new DummyEventGenerator();

		// dont care about that exceptions in this test case
		try {
			junitManager.add(eventGenerator, managedFacet);
		} catch (DoubleEventTypeOccuranceException e) {

			e.printStackTrace();
		} catch (NotRegisteredManagedFacetReference e) {

			e.printStackTrace();
		}

		((DummyEventGenerator) eventGenerator).populateEventStore();
		((DummyEventGenerator) eventGenerator).populateEventStore();
	}

	/**
	 * Evaluates whether a metric extractor can be added to the GAMF and if it
	 * is granted access to the event store as envisioned and computes metrics
	 * as specified.
	 */

	@Test
	public void extractingMetric() {
		IMetricExtractor metricExtractor = new DummyMetricExtractor();
		IEventTrigger trigger = new DummyTrigger();

		try {
			metricExtractor.extractMetricResult();
			fail("the metric extractor is not registered - it should fail here when trying to evaluate something (which involves an access to the GAMF's event store).");
		} catch (MetricExtractionException e) {
			//test should have failed here!
		}

		try {
			junitManager.add(metricExtractor, trigger, managedFacet);
		} catch (Exception e) {
			e.printStackTrace();
		}

		IMetricResult resultingMetricValue = null;
		try {
			resultingMetricValue = metricExtractor.extractMetricResult();
		} catch (MetricExtractionException e1) {
			fail("no reason here for this metric extraction failing");
		}

		Object resultingNbr = resultingMetricValue.getMetricValue();
		if (resultingNbr == null) {
			fail("we have populated the event store! there must be a value!");
		}

		if (resultingNbr instanceof Integer) {
			Integer nbr = (Integer) resultingNbr;
			if (nbr != 2) {
				fail("nbr is expected to be 2 but was " + nbr);
			}

		} else {
			fail("nbr must be an integer!");
		}
	}
}
