/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.addons.junittests;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;
import gamf.framework.GenericAutonomicManagementFramework;
import gamf.framework.exceptions.ConfigurationError;
import gamf.framework.exceptions.DoubleEventTypeOccuranceException;
import gamf.framework.exceptions.NoEffectorException;
import gamf.framework.exceptions.NotRegisteredManagedFacetReference;
import gamf.interfaces.framework.IGAMF;
import gamf.interfaces.framework.IManagedFacet;
import gamf.interfaces.systemAdapter.IEffector;
import gamf.interfaces.systemAdapter.IEventGenerator;
import gamf.interfaces.systemAdapter.IPolicyEvaluator;

import org.junit.BeforeClass;
import org.junit.Test;

/**
 * This tests policy evaluators. It is verified if a policy evaluator
 * interactions with the GAMF as envisioned.
 * 
 * 
 * @author markus
 * 
 */

public class PeriodicalPolicyEvaluationTests {

	static IGAMF junitManager;

	static IManagedFacet managedFacet;

	static String junitManagedFacetName1;
	static IEffector effector;
	String junitManagedFacetSimilarToName1;

	static IEventGenerator eventGenerator;

	/**
	 * Creates a manager, an managedFacet, adds an eventGenerator and a
	 * periodically evaluated metric.
	 * 
	 * @throws Exception
	 * 
	 */

	@BeforeClass
	public static void initialize() throws Exception {
		// ////////////////////////////////////////
		// GAMF setup (register all system adapter - besides a policy evaluator)
		junitManager = new GenericAutonomicManagementFramework();
		junitManagedFacetName1 = JunitTestRegister.MANAGEDFACETNAME1;
		managedFacet = junitManager
				.registerManagedFacet(junitManagedFacetName1);
		effector = new DummyEffector();
		junitManager.add(effector, managedFacet);
		// ////////////////////////////////////////
		// initiate dummy tuning knob
		effector.set(JunitTestRegister.TUNEABLEPARAMETER);

	}

	/**
	 * Evaluates if a tune-able parameter is changed (via the effector) after a
	 * specific time span due to the policy evaluator. Test fails if the
	 * parameter hasn't changed.
	 * 
	 * @throws ConfigurationError
	 * @throws NoEffectorException
	 * @throws DoubleEventTypeOccuranceException
	 * @throws NotRegisteredManagedFacetReference
	 * 
	 */

	@Test
	public void testPolicy() throws ConfigurationError,
			NotRegisteredManagedFacetReference,
			DoubleEventTypeOccuranceException, NoEffectorException {

		int evaluationTimeSpan = 1500;
		IPolicyEvaluator policyEvaluator = new DummyPolicyEvaluator(effector);
		try {
			junitManager.add(policyEvaluator, evaluationTimeSpan, managedFacet);
		} catch (Exception e) {
			fail("the policy evaluator is expected to be added to the GAMF w/o a problem!");
		}

		// lets wait ~2 seconds before events are generated
		// that needs to be done to satisfy the assert conditions
		// otherwise the dummy policy evaluator might haven't done anything

		try {
			Thread.sleep(evaluationTimeSpan + 100);
		} catch (InterruptedException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		int initalTuneAbleParameterValue = JunitTestRegister.TUNEABLEPARAMETER;
		int newTuneAbleParameterValue = ((Integer) effector.get()).intValue();
		assertTrue(initalTuneAbleParameterValue != newTuneAbleParameterValue);
		assertTrue(initalTuneAbleParameterValue < newTuneAbleParameterValue);
		assertTrue(initalTuneAbleParameterValue+3 > newTuneAbleParameterValue);

	}

}
