/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.framework;

import java.util.Set;

 
import gamf.interfaces.framework.IEventStore;
import gamf.interfaces.framework.IGAMF;
import uk.ac.standrews.cs.nds.eventModel.IEvent;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventBus;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventConsumer;
import uk.ac.standrews.cs.nds.util.Diagnostic;

/**
 * The eventRecorder listens to the eventBus specified in the constructor. 
 * It "is interested" in all eventTypes stored in the manager's eventTypeRegister.
 * Received events are stored in the manager's eventLog. 
 *  
 * @author markus
 *
 */

@SuppressWarnings("unused")
public class EventRecorder implements IEventConsumer {

	private Set<String> eventTypesRegister;
	
	private static IEventStore eventStore;

	private IEventBus managerEventBus;

	public EventRecorder(IEventBus managerEventBus, IGAMF manager) {
		
		this.managerEventBus = managerEventBus;
		if (managerEventBus != null) managerEventBus.register(this);

		eventStore = manager.getEventStore();
		eventTypesRegister = manager.getEventTypesRegister();
	}

	public boolean interested(IEvent event) {

		return eventTypesRegister.contains(event.getType());
	}

	public void receiveEvent(IEvent event) {

		//just add it - interesed must have returned true if it is registered
		
		//Diagnostic.trace(DiagnosticLevel.INIT,"event received :"+event.getType());
	
		eventStore.add(event);
	}
}
