/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.framework;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import gamf.framework.exceptions.EventStoreExecption;
import gamf.interfaces.framework.IEventStore;
import uk.ac.standrews.cs.nds.eventModel.IEvent;
import uk.ac.standrews.cs.nds.eventModel.ITimeStampedEvent;

/**
 * Enables access to the stored events, and offers some integrated search functionality.
 * 
 * @author markus
 * 
 */

@SuppressWarnings("serial")
public class EventStore extends Vector<IEvent> implements IEventStore {

	public EventStore() {
		super();
	}

	/**
	 * Returns a list of events of the specified eventType.
	 * 
	 * @param key the eventType to look for
	 * 
	 * @return A list of the events of the specified eventType.
	 * 
	 */

	public synchronized List<IEvent> getAllOfType(String key) {

		Vector<IEvent> searchResult = new Vector<IEvent>();

		Iterator<IEvent> eventsOfType = iterator();

		while (eventsOfType.hasNext()) {
			IEvent event = eventsOfType.next();
			if (event.getType().equals(key)) {
				searchResult.add(event);
			}
		}

		if(searchResult.size()==0){
			return null;
		}
		return searchResult;
	}

	public List<IEvent> get(String key, String searchPattern) {
		// TODO implement search pattern
		return null;
	}

	public List<ITimeStampedEvent> getLatestEventsOfType(String eventType, Long oldest) throws EventStoreExecption {
		List<IEvent> events = getAllOfType(eventType);
		List<ITimeStampedEvent> eventsToReturn = new ArrayList<ITimeStampedEvent>();
		if (events != null) {
			if (events.get(0) instanceof ITimeStampedEvent) {
				for(IEvent event: events){
					ITimeStampedEvent timeStampedEvent = (ITimeStampedEvent)event;
					if(timeStampedEvent.getEventCreationTime()>=oldest){
						eventsToReturn.add(timeStampedEvent);	
					}
				}
			}else {
				throw new EventStoreExecption(eventType+" is not a timestamped event ");
			}
		}
		
		
		return eventsToReturn;
	}

}
