/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.framework;

import java.util.HashSet;
import java.util.Iterator;

import gamf.interfaces.framework.IManagedFacet;
import gamf.interfaces.systemAdapter.ISystemAdapter;

/**
 * Represents an managedFacet and a group of system adapters associated with the specified managedFacet. 
 * <p>
 * The system adapters are referred to as managedFacet components after they are associated with an managedFacet.  
 * An managedFacet serves as registration to maintain the correct functionality of the autonomic management if system adapters are multiply used.
 * That includes, not allowing an managedFacet's  system adapter to be removed if it is still in use to manage another managedFacet.   
 * System adapter programmers can modify an managedFacet through IGenericManager. 
 * </p>    
 * 
 * 
 * @author markus
 *
 */
@SuppressWarnings("serial")
public class ManagedFacet extends HashSet<ISystemAdapter> implements IManagedFacet {
	
	private String managedFacetName;
		
	public ManagedFacet(String managedFacetName){
		super();
		this.managedFacetName=managedFacetName;
	}

	public void addSystemAdapter(ISystemAdapter systemAdapter) {
		
		add(systemAdapter);
	}
		
	public String getManagedFacetName() {
	
		return managedFacetName;
	}

	public Iterator<ISystemAdapter> getManagedFacets() {

		return iterator();
	}

	public void removeSystemAdapter(ISystemAdapter systemAdapter) {
		
		// TODO see if the system adapter can be removed savetly - killing threads ....
	}
}
