/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.framework;

import gamf.interfaces.framework.ITrigger;
import gamf.interfaces.framework.IMetricResult;
import gamf.interfaces.framework.IMetricValueStore;
import gamf.interfaces.systemAdapter.IMetricExtractor;
import uk.ac.standrews.cs.nds.eventModel.IEvent;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventBus;

/**
 * Offers a way to trigger the metric extraction. 
 * In this implementation of the GAMF it is triggered by the trigger on the arrival or an event.  
 * It checks if the evaluated metricResult contains an event. 
 * If it does it publishes the event after storing the metricResult in the metricResultStore. 
 * 
 * @author markus
 *
 */

public class MetricExtractor extends Thread implements ITrigger {
	
	IMetricExtractor metric;
	IMetricValueStore metricResultStore;
	IMetricResult metricResult;
	IEventBus eventBus;
	
	public MetricExtractor(IMetricExtractor metric, IMetricValueStore metricResultStore, IEventBus eventBus) {
	
		this.metric=metric;
		this.metricResultStore=metricResultStore;
		this.eventBus = eventBus;
	}
	 
	
	public void evaluate() {
		
		try {
			metricResult=metric.extractMetricResult();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		metricResultStore.add(metricResult);
		
		IEvent event=metricResult.getExtractionEvent();
		if(event!=null){
			eventBus.publishEvent(event);
		}
	}

	public String getSystemAdapterCategory() {
		// TODO Auto-generated method stub
		return "FIXME";
	}

	public String getSystemAdapterIdentifier() {
		// TODO Auto-generated method stub
		return "FIXME";
	}
}
