/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.framework;

import java.util.Date;

import gamf.interfaces.framework.IMetricResult;
import uk.ac.standrews.cs.nds.eventModel.IEvent;

/**
 * Holds all relevant data generated by a metric extractor. It can contain
 * (optionally) an event which is published by the GAM after the metric is
 * stored.
 * 
 * @author markus
 * 
 */
public class MetricResult implements IMetricResult {

	String type;
	Date creationDate;
	Object resultValue;
	IEvent event;

	public MetricResult(String metricResultType, Object resultValue) {
		this.type = metricResultType;
		creationDate = new Date();
		this.resultValue = resultValue;
		event = null;
	}

	public MetricResult(String metricResultType, Object resultValue,
			IEvent event) {
		this.type = metricResultType;
		creationDate = new Date();
		this.resultValue = resultValue;
		this.event = event;
	}

	public String getType() {
		return this.type;
	}

	public Object getMetricValue() {

		return resultValue;
	}

	public Date getTime() {

		return creationDate;
	}

	public IEvent getExtractionEvent() {

		return event;
	}

}
