/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.framework;

import gamf.interfaces.framework.IMetricValueStore;
import gamf.interfaces.framework.IPeriodicalTrigger;
import gamf.interfaces.systemAdapter.IMetricExtractor;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventBus;

/**
 * Evaluates a (at creation time) specified metric every (at creation time) specified time period and stores the result.
 * It does not check if there are any events to send.
 * @author markus
 *
 */

public class PeriodicalMetricExtractor extends MetricExtractor implements IPeriodicalTrigger {

	private int waitPeriod;


	
	public PeriodicalMetricExtractor(IMetricExtractor metric,int waitPeriod,IMetricValueStore metricResultStore, IEventBus eventBus) {
		super(metric, metricResultStore, eventBus);
		this.waitPeriod = waitPeriod;
		this.setName(metric.getSystemAdapterIdentifier()+"_x_THREAD");
		
	}


	public void run() {
		while(true){
			try { 
				sleep(waitPeriod);
				evaluate();
			} catch (InterruptedException e) {
				e.printStackTrace();
			}	
		}
		



		
	}

	public void setWaitperiod(int newWaitPeriod) {
		
		//TODO check if there is a big difference and handle thread according to this. 
		
		this.waitPeriod=newWaitPeriod;

	}



}
