/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.framework;

import gamf.framework.exceptions.EvaluationException;
import gamf.framework.exceptions.PolicyEvaluationException;
import gamf.interfaces.framework.ITrigger;
import gamf.interfaces.systemAdapter.IPolicyEvaluator;

/**
 * Evaluates a (at creation time) specified policy everytime evaluate is called
 * (i.e. by the trigger)
 * 
 * @author markus
 * 
 */

public class PolicyEvaluator extends Thread implements ITrigger {

	IPolicyEvaluator policy;
	String policyEvaluatorID = "GAMF Periodic Policy Evaluator ",
			policyEvaluatorCategory = "GAMF internal Component";

	public PolicyEvaluator(IPolicyEvaluator policy) {
		this.policy = policy;
	}

	public void evaluate() throws EvaluationException {

		try {
			policy.evaluatePolicy();
		} catch (PolicyEvaluationException e) {
			String msg = "StandardPolicyEvaluator's evaluation failed with msg:"
					+ e.getMessage();
			throw new EvaluationException(msg);
		}
	}

	public String getSystemAdapterCategory() {
		return policyEvaluatorCategory;
	}

	public String getSystemAdapterIdentifier() {
		return policyEvaluatorID;
	}
}
