/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.framework;

import gamf.framework.exceptions.EvaluationException;
import gamf.interfaces.framework.ITrigger;
import gamf.interfaces.framework.IEventTrigger;
import uk.ac.standrews.cs.nds.eventModel.IEvent;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventBus;

/**
 * This trigger is registered with the eventBus and listens to a (on creation time) specified eventtype.
 * Whenever an event with such an eventtype is received - a (at creation time) specified evaluator is called.  
 * 
 * @author markus
 *
 */

public class Trigger implements IEventTrigger {

	private IEventBus managerEventBus;

	private ITrigger evaluator;

	private String eventType;

	public Trigger(String eventNameToBeTriggerendOn,
			ITrigger triggeredMetricEvaluator, IEventBus managerEventBus) {
		this.managerEventBus = managerEventBus;
		this.evaluator = triggeredMetricEvaluator;
		this.eventType = eventNameToBeTriggerendOn;
		managerEventBus.register(this);
				
	}

	public Trigger(String eventNameToBeTriggerendOn) {
		this.eventType = eventNameToBeTriggerendOn;
	}

	public void setEvaluator(ITrigger evaluator) {
		this.evaluator = evaluator;
	}

	public void setEventType(String eventType) {
		this.eventType = eventType;

	}

	public void setEventBus(IEventBus eventBus) {
		this.managerEventBus = eventBus;
		managerEventBus.register(this);
	}

	public boolean interested(IEvent event) {
			
		return event.getType().equals(eventType);
		

	}

	public void receiveEvent(IEvent event) {

		if (evaluator != null) {
				try {
					evaluator.evaluate();
				} catch (EvaluationException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			
		}
	}

	public String getSystemAdapterCategory() {
		// TODO Auto-generated method stub
		return "FIXME";
	}

	public String getSystemAdapterIdentifier() {
		// TODO Auto-generated method stub
		return "FIXME";
	}
}
