/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.framework;

import java.util.List;

import gamf.framework.exceptions.EventStoreExecption;
import uk.ac.standrews.cs.nds.eventModel.IEvent;
import uk.ac.standrews.cs.nds.eventModel.ITimeStampedEvent;

/**
 * Allows "easy access" to the stored events.
 * 
 *  
 */
public interface IEventStore extends List<IEvent> {
	
	/**
	 * Returns the events to which this store maps the specified event type.
	 * 
	 * @param key - the event type
	 * @return a List of events (ordered by timestamp, latest first)
	 */
	
	List<IEvent> getAllOfType(String key);

	/**
	 * Returns the events to which this store maps the specified key and where the search pattern applies.
	 * 
	 * @param key - the event type
	 * @param searchPattern - improves the search process by selecting only a subset of the entire log, 
	 * (eventType="name", eventInformation="part of information", firstTime it occurs (timestamp), latestTime it occurse(timestamp), maximum number of results)  
	 * @return a List of events (ordered by timestamp, latest first)
	 * 
	 */
	List<IEvent> get(String key, String searchPattern);
	
	/**
	 * 
	 * 
	 * @param eventType the type of events we are looking for. 
	 * @param oldest the timestamp of the oldest event we are looking for [ms]
	 *   
	 * @return Returns all events of type 'eventType', created between call time and (incl.) 'oldest' 
	 * @throws EventStoreExecption 
	 */
	List<ITimeStampedEvent> getLatestEventsOfType(String eventType,Long oldest) throws EventStoreExecption;
}