/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.framework;

import gamf.interfaces.systemAdapter.ISystemAdapter;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventBus;
import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventConsumer;

/**
 * Allows the configuration of a Trigger. 
 * <p>
 * A trigger listens to an event bus; when it receives a specified event type
 * it triggers a specified metric evaluator or a policy evaluator. 
 * </p><p>
 * This interface must also be implemented by the system adapter programmer if the programmer
 * develops a customised trigger. 
 * </p>
 *
 * @author markus
 *
 */

public interface IEventTrigger extends IEventConsumer, ISystemAdapter {

	
	/**
	 * Sets the evaluator to be called on the arrival of a specified event type. 
	 * @param evaluator invokes the specified metric-extraction or policy-evaluation. 
	 */
	
	void setEvaluator(ITrigger evaluator);

	/**
	 * Sets which event type the trigger has to watch for.
	 * 
	 * @param eventType a String that defines the event type
	 */
	
	void setEventType(String eventType);
	
	/**
	 * Sets the eventbus the trigger is listening to. 
	 * 
	 * @param eventbus the eventbus the trigger is listening to
	 */
	
	void setEventBus(IEventBus eventbus);
}