/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.framework;

import java.util.Date;

import uk.ac.standrews.cs.nds.eventModel.IEvent;



/**
 * Describes the result of a metric extraction and includes some meta data. 
 * <p>
 * It allows the system adapter programmer read only access to a metric result. 
 * </p>
 *   
 * @author markus
 *
 */

public interface IMetricResult {
	/**
	 * Returns the name of the metric value. 
	 * 
	 * @return the name of the metric value
	 */
	String getType();
	
	/**
	 * Returns the result of the metric extraction. 
	 * @return the result of this metricValue
	 */

	Object getMetricValue();
	
	/**
	 * Returns the time the metric value was evaluated. 
	 * 
	 * @return the time the metric value was evaluated.
	 */
	Date getTime();
	
	/**
	 * Returns an event to be sent after the value is stored. 
	 * 
	 * @return the event to be sent after the value is stored
	 */
	
	IEvent getExtractionEvent();
}
