/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.framework;

import java.util.List;


/**
 * Enables access to the stored metricValues, and offers some integrated search functionality.
 * 
 *  
 */

public interface IMetricValueStore extends List<IMetricResult>{

	/**
	 * Returns the metricValue to which this store maps the specified key.
	 * 
	 * @param type - the metric result type
	 * @return a set of metricValues
	 */
	List<IMetricResult> getAllOfType(String type);
	
	/**
	 * Returns the metricValue to which this store maps the specified key and where the search pattern applies.
	 * 
	 * @param key - the metric result type
	 * @param searchPattern improves the search process by selecting only a subset of the entire log.  
	 * @return a set of metricValues
	 * 
	 */
	List<IMetricResult> get(String key, String searchPattern);	
}