/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.framework;

import gamf.framework.exceptions.EvaluationException;
import gamf.interfaces.systemAdapter.ISystemAdapter;

/**
 * 
 * Describes the functionality of either a metric or a policy evaluation - a simple interface which is offering a way to trigger a system adapter evaluation or extraction. 
 * <p>
 * A simple evaluator is instantiated with a reference to either the metric or the policy it is the scheduling the evaluation of.
 * A caller (mainly an internal framework component) indirectly calls the policy or metric through this interface. 
 * </p>
 *   
 * @author markus
 *
 */

public interface ITrigger extends ISystemAdapter {

	/**
	 *  Triggers the evaluation of the associated metric or policy. 
	 * @throws EvaluationException 
	 * 
	 */
	void evaluate() throws EvaluationException ;

	/**
	 * 	Hook to start the evaluator thread
	 *
	 */
	
	void start();
}