/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.systemAdapter;

import gamf.framework.exceptions.TypeMissMatch;

/**
 * Sets and gets a tunable parameter that an autonomic controlled managedFacet depends on.  
 * <p>
 * An effector provides a link between the manager and the system that is controlled. 
 * </p>
 * <p>
 * An effector is also used to control parameters of the manager which directly influence policy objectives. 
 * For example if managers are nested and the policy evaluation could favour either performance or accuracy.
 * In that case the entire manager appears for the higher level manager as system.
 * </p>
 * 
 * @author markus
 *
 */
public interface IEffector extends ISystemAdapter{
	/**
	 * Sets a new value for the tunable parameter.
	 * 
	 * @param value to set
	 * @throws TypeMissMatch 
	 */
	
	void set(Object value) throws TypeMissMatch;
	/**
	 * Returns the current value of the tunable parameter.
	 * 
	 * @return the object to change
	 */

	Object get();
	
	
	
	

}