/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.systemAdapter;

import gamf.framework.exceptions.EventGenerationException;

import java.util.Iterator;
import java.util.List;
import java.util.Map;

import uk.ac.standrews.cs.nds.eventModel.eventBus.busInterfaces.IEventBus;



/**
 * Gathers information from the system and sends it to the framework.
 * <p>
 * Whenever something the managedFacet is depending on happens - the event generator collects
 * that information and sends it as an event to the framework.
 * An event generator specifies which event types can be sent to the framework.
 * </p>
 * <p>
 * If the system is designed with the use of the generic autonomic management framework
 * in mind, an event generator could be already integrated in the system.
 * The event generator interface may also be implemented into metrics and policies to support the "triggered by events" capability of the framework.
 *</p>
 * @author markus
 *
 */

public interface IEventGenerator extends ISystemAdapter{

	/**
	 * Sets the event bus
	 * @param eventBus event stream (see NDS library)
	 */
	void setEventBus(IEventBus eventBus);

	/**
	 * Returns the event types the event generator is able to send to the bus
	 *
	 * @return a Set of event types (Strings)
	 */
	Iterator<String> queryEventTypes();
	
	/**
	 * Triggers the generation of an event with some messages attached. 
	 * 
	 * @param eventType
	 * @param msgs messages identified with a message ID
	 */
	void triggerEventGeneration(String eventType,  Map<String,String> msgs)throws EventGenerationException;
	
	/**
	 * Triggers the generation of an event with a single message attached.
	 * This is a short cut to above function, with DEFAULT_EVENT_MSG_ID as default message ID. 
	 * @param eventType
	 * @param msg - a message
	 */
	void triggerEventGeneration(String eventType, String msg)throws EventGenerationException;
	
	/**
	 * Triggers the generation of an event without any messages attached.
	 * 
	 * @param eventType
	 * @throws EventGenerationException 
	 */
	void triggerEventGeneration(String eventType) throws EventGenerationException;
	
}