/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.systemAdapter;

import gamf.framework.exceptions.ConfigurationError;
import gamf.framework.exceptions.MetricExtractionException;
import gamf.interfaces.framework.IGAMF;
import gamf.interfaces.framework.IMetricResult;

/**
 *  Configures a metrics and invokes it's evaluation and returns the result of the evaluation.
 *	<p>
 *  A metric performs the evaluation of existing data by aggregating events of one or more event types.
 *  </p>
 *  <p>
 *  Existing data can be obtained from the EventStore(IEventStore) and the MetricResultStore (IMetricResultStore).
 *  The metric may also send events to the event bus to e.g. trigger a policy evaluation. 
 *  The scheduling of a metric evaluation can be configured during registration of the metric with the framework.
 *	</p>
 *  @author markus
 *
 */

public interface IMetricExtractor extends ISystemAdapter {

	/**
	 * Invokes the evaluation of the metric and returns the result.
	 *
	 * @return  the evaluation's result.
	 * @throws ConfigurationError 
	 * @throws Exception 
	 */

	public  IMetricResult  extractMetricResult() throws MetricExtractionException;
	
	/**
	 * Sets a reference to the GAMF the metric is registered with (added to).  
	 * This allows a system adapter programmer to access i.e. the eventStore. 
	 *
	 */
	
	public void setManagerReferece(IGAMF manager);
	
}