/*
 *  ASA Library
 *  Copyright (C) 2004-2008 Distributed Systems Architecture Research Group
 *  http://asa.cs.st-andrews.ac.uk/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package gamf.interfaces.systemAdapter;

import java.util.Iterator;

import gamf.framework.exceptions.PolicyEvaluationException;
import gamf.interfaces.framework.IGAMF;

/**
 * Invokes a policy evaluation.
 * <p>
 * A policy takes metric results (and or events) from a local cache or the
 * metric result store (see IMetricResultStore) (and/or events - from the event
 * store (see IEventStore) ) to decide which action needs to take place. The
 * policy also sends events to the framework. The scheduling of a policy
 * evaluation can be configured during registration of the policy with the
 * framework.
 * </p>
 */

public interface IPolicyEvaluator extends ISystemAdapter {

	/**
	 * triggers the policy evaluation
	 */

	public void evaluatePolicy() throws PolicyEvaluationException;

	/**
	 * Sets a reference to the GAMF the metric is registered with (added to).
	 * This allows a system adapter programmer to access i.e. the eventStore.
	 * 
	 */

	public void setManagerReferece(IGAMF manager);

	/**
	 * Each policy evaluator is supposed to provide a information about the
	 * effectors it is using. This method provides an interval to add them.
	 * 
	 * @param effector
	 */
	public void associateEffectorWithPolicyEvaluator(IEffector effector);

	/**
	 * Returns a set of effectors (used by this policy)
	 * 
	 * @return the set of effectors used by this policy
	 */

	public Iterator<IEffector> getEffectors();

}